# This file is imported from __init__.py and exec'd from setup.py
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing_extensions import Final

__version__: 'Final[str]' = "1.3.0.post0"
